@@ -17,7 +17,7 @@ import attr
 # The Segment type is used instead of a generic type because of another bug with the
 # mypy-attrs plugin.
 # https://github.com/python/mypy/issues/8625#issuecomment-632720205
-def _tuple(iterable: Iterable[Segment],) -> Tuple[Segment, ...]:
+def _tuple(iterable: Iterable[Segment]) -> Tuple[Segment, ...]:
     return tuple(iterable)
 
 
