@@ -44,6 +44,7 @@ class VocabularyTerm(Segment):
             "break statement": "Immediately end a loop",
             "Chained comparison": "An expression with more than one comparison operator",  # noqa: E501
             "Class": "A blueprint for creating something specific",
+            "Collection": "A grouping of information",
             "Collision": "When sprites touch or overlap",
             "Comment": "A note that the computer ignores",
             "Comparison operator": "Compares two values and gives a yes or no answer",
@@ -58,6 +59,8 @@ class VocabularyTerm(Segment):
             "Decrement": "Decrease a variable by an amount",
             "Documentation": "A written explanation of how to use code",
             "Duration": "The amount of time between two moments",
+            "Element": "A value in a collection at a position",
+            "Element query": "A question about an element in a collection",
             "elif clause": "When all prior conditions are false, runs a section of code when the condition is true",  # noqa: E501
             "else clause": "When all prior conditions are false, runs a section of code as a last alternative",  # noqa: E501
             "Equal to": "Are the two values the same?",
@@ -68,21 +71,31 @@ class VocabularyTerm(Segment):
             "Feature": "Something a program can do",
             "Float": "A number with a decimal point",
             "Floor division operator": "Rounds the quotient down to a whole number after division",  # noqa: E501
-            "for loop": "A loop that runs a specific number of times",  # noqa: E501
+            "for loop": "A loop that runs a specific number of times",
+            "For-each loop": "A loop that iterates over each element in a collection",
             "Frame": "One still image within an animation, usually one iteration of a loop",  # noqa: E501
             "Function": "A named code action that can be used in a program",
             "Greater than": "Is the left value bigger than the right value?",
             "Header comment": 'A multi-line comment at the top of a program surrounded by `"""` marks',  # noqa: E501
             "if statement": "Runs a section of code when the condition is true",
             "Increment": "Increase a variable by an amount",
+            "Index": "The zero-based position of an element in a collection",
             "Infinite loop": "A loop with a condition that will always be True",
             "Instance": "A specific copy created from a class",
             "Integer": "A number written without a decimal point",
             "Interaction": "A cycle of user input and program output that influence each other",  # noqa: E501
+            "Iterate": "Operate on the elements of a collection, one at a time in sequential order",  # noqa: E501
             "Iteration": "One repetition of a loop",
             "Key constant": "An unchanging value representing a key on the keyboard",
+            "Length": "The number of elements in a collection",
             "Less than": "Is the left value smaller than the right value?",
             "Library": "A collection of code from outside the program",
+            "List": "A changeable collection of ordered elements",
+            "List append": "Add an element to the end of a list",
+            "List delete": "Take an element out of a list by its index",
+            "List extend": "Copy all elements of one list to the end of another list",
+            "List insert": "Add an element to a list at a position",
+            "List remove": "Take an element out of a list by its value",
             "Literal": "A value you can literally see",
             "Logical operator": "Combines or modifies a boolean",
             "Loop else clause": "A clause following a loop that runs unless the loop ends with break",  # noqa: E501
@@ -142,6 +155,7 @@ class VocabularyTerm(Segment):
             "break statement": "3.2.1",
             "Chained comparison": "2.2.2",
             "Class": "3.3.1",
+            "Collection": "4.1.1",
             "Collision": "3.6.2",
             "Comment": "1.1.2",
             "Comparison operator": "2.1.2",
@@ -156,6 +170,8 @@ class VocabularyTerm(Segment):
             "Decrement": "1.4.1",
             "Documentation": "1.2.2",
             "Duration": "3.6.1",
+            "Element": "4.1.1",
+            "Element query": "4.2.1",
             "elif clause": "2.2.1",
             "else clause": "2.2.1",
             "Equal to": "2.1.1",
@@ -167,20 +183,30 @@ class VocabularyTerm(Segment):
             "Float": "1.3.1",
             "Floor division operator": "2.3.2",
             "for loop": "3.7.1",
+            "For-each loop": "4.1.1",
             "Frame": "3.5.1",
             "Function": "1.2.1",
             "Greater than": "2.1.2",
             "Header comment": "1.1.2",
             "if statement": "2.1.1",
             "Increment": "1.4.1",
+            "Index": "4.1.2",
             "Infinite loop": "3.1.1",
             "Instance": "3.3.1",
             "Integer": "1.3.1",
             "Interaction": "3.6.1",
+            "Iterate": "4.1.1",
             "Iteration": "3.1.1",
             "Key constant": "3.6.1",
+            "Length": "4.1.2",
             "Less than": "2.1.2",
             "Library": "1.2.1",
+            "List": "4.1.1",
+            "List append": "4.2.2",
+            "List delete": "4.2.2",
+            "List extend": "4.2.2",
+            "List insert": "4.2.2",
+            "List remove": "4.2.2",
             "Literal": "1.3.1",
             "Logical operator": "2.4.1",
             "Loop else clause": "3.2.1",
